summaryrefslogtreecommitdiff
path: root/test/ClientTest.h
diff options
context:
space:
mode:
authorPatrick Ohly <patrick.ohly@intel.com>2011-11-24 16:35:10 +0100
committerPatrick Ohly <patrick.ohly@intel.com>2011-11-28 16:08:00 +0000
commit26f31f5be6dd461d1545796a264ccc51bc67c466 (patch)
treeea94abcc7f6a6ce27ee54aed8a9ac7f2e837520d /test/ClientTest.h
parent726ac732eacb319f61260f227ee759bb4bef198e (diff)
testing: added Source::*::testRemoveProperties
This is primarily for ActiveSync where the test failed until support for removing properties was added to activesyncd. Is also applied to all other sources, just in case. The EDS contact backend needs to keep the X-EVOLUTION-FILE-AS property because EDS keeps adding it, which makes it impossible to test its removal.
Diffstat (limited to 'test/ClientTest.h')
-rw-r--r--test/ClientTest.h7
1 files changed, 5 insertions, 2 deletions
diff --git a/test/ClientTest.h b/test/ClientTest.h
index 09657fe5..7bb0d57d 100644
--- a/test/ClientTest.h
+++ b/test/ClientTest.h
@@ -302,11 +302,13 @@ class ClientTest {
static void getItems(const std::string &file, std::list<std::string> &items, std::string &realfile);
/**
* utility function for importing items with blank lines as separator
*/
static std::string import(ClientTest &client, TestingSyncSource &source,
const ClientTestConfig &config,
- const std::string &file, std::string &realfile);
+ const std::string &file, std::string &realfile,
+ std::list<std::string> *luids);
/**
* utility function for comparing vCard and iCal files with the external
@@ -587,6 +589,7 @@ public:
virtual void testChanges();
virtual void testImport();
virtual void testImportDelete();
+ virtual void testRemoveProperties();
virtual void testManyChanges();
virtual void testLinkedItemsParent();
virtual void testLinkedItemsChild();
@@ -302,11 +302,13 @@ class ClientTest {
static void getItems(const std::string &file, std::list<std::string> &items, std::string &realfile);
/**
- * utility function for importing items with blank lines as separator
+ * utility function for importing items with blank lines as separator,
+ * for ClientTestConfig::m_import
*/
static std::string import(ClientTest &client, TestingSyncSource &source,